# Installation

conda-lock is available through `pip`, `conda` and `mamba`.

=== "pip"

    ```sh
    pip install conda-lock
    ```

    Install with pip support
    ```sh
    pip install conda-lock[pip_support]
    ```

=== "conda"

    ```sh
    conda install -c conda-forge conda-lock
    ```

=== "mamba"

    ```sh
    mamba install -c conda-forge conda-lock
    ```
